@@ -17,7 +17,12 @@ use glib::thread_guard::ThreadGuard;
 use gtk::glib;
 use gtk::prelude::*;
 
-#[cfg(any(target_os = "macos", target_os = "windows", feature = "gst-gl"))]
+#[cfg(any(
+    target_os = "macos",
+    target_os = "windows",
+    feature = "gst-gl",
+    feature = "dmabuf"
+))]
 use gtk::gdk;
 
 #[cfg(any(target_os = "macos", target_os = "windows", feature = "gst-gl"))]
@@ -29,6 +34,7 @@ use gst_gl::prelude::*;
 use gst::prelude::*;
 use gst::subclass::prelude::*;
 use gst_base::subclass::prelude::*;
+#[allow(unused_imports)]
 use gst_video::{prelude::*, subclass::prelude::*};
 
 use once_cell::sync::Lazy;
@@ -857,6 +863,9 @@ impl PaintableSink {
                 }
             });
 
+            #[cfg(feature = "gtk_v4_10")]
+            window.set_visible(true);
+            #[cfg(not(feature = "gtk_v4_10"))]
             window.show();
 
             *window_guard = Some(ThreadGuard::new(window));
